@@ -3,18 +3,11 @@ use strict;
 use warnings;
 use CairoX::Sweet::Standard;
 
-our $VERSION = '0.0103'; # VERSION
+our $VERSION = '0.0104'; # VERSION
 # PODNAME: CairoX::Sweet
 # ABSTRACT: Wraps Cairo for easier drawing
 
-package CairoX::Sweet;
-
-sub new {
-    shift;
-    CairoX::Sweet::Wrap->new(@_);
-}
-
-class CairoX::Sweet::Wrap using Moose {
+class CairoX::Sweet using Moose {
 
     use Cairo;
     use Type::Utils qw/enum/;
@@ -86,7 +79,8 @@ class CairoX::Sweet::Wrap using Moose {
         return $class->new($width, $height, %args);
     }
 
-    method add_path(Path $path, :$close = 0) {
+    method add_path(Path $path, Bool :$close = 0
+    ) {
         if($path->has_background_color) {
             foreach my $command ($path->all_commands) {
                 my $method = $command->method;
@@ -134,7 +128,7 @@ CairoX::Sweet - Wraps Cairo for easier drawing
 
 =head1 VERSION
 
-Version 0.0103, released 2015-01-11.
+Version 0.0104, released 2015-01-16.
 
 =head1 SYNOPSIS
 
