@@ -3,10 +3,11 @@ use strict;
 use warnings;
 use CairoX::Sweet::Standard;
 
-our $VERSION = '0.0103'; # VERSION
+our $VERSION = '0.0104'; # VERSION
 # PODNAME: CairoX::Sweet::Core::LineTo
+# ABSTRACT: Draw a line_to
 
-class CairoX::Sweet::Core::LineTo with CairoX::Sweet::Role::PathCommand using Moose {
+class CairoX::Sweet::Core::LineTo using Moose with CairoX::Sweet::Role::PathCommand {
 
     use CairoX::Sweet::Core::Point;
 
@@ -47,11 +48,11 @@ __END__
 
 =head1 NAME
 
-CairoX::Sweet::Core::LineTo
+CairoX::Sweet::Core::LineTo - Draw a line_to
 
 =head1 VERSION
 
-Version 0.0103, released 2015-01-11.
+Version 0.0104, released 2015-01-16.
 
 =head1 SOURCE
 
