@@ -3,9 +3,9 @@ use strict;
 use warnings;
 use CairoX::Sweet::Standard;
 
-our $VERSION = '0.0103'; # VERSION
+our $VERSION = '0.0104'; # VERSION
 # PODNAME: CairoX::Sweet::Path
-# ABSTRACT:
+# ABSTRACT: Handles a path
 
 class CairoX::Sweet::Path using Moose {
 
@@ -148,11 +148,11 @@ __END__
 
 =head1 NAME
 
-CairoX::Sweet::Path - class CairoX::Sweet::Path using Moose {
+CairoX::Sweet::Path - Handles a path
 
 =head1 VERSION
 
-Version 0.0103, released 2015-01-11.
+Version 0.0104, released 2015-01-16.
 
 =head1 SYNOPSIS
 
